@@ -13,8 +13,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import json
 from itertools import chain
+import json
 
 from django.template.loader import get_template
 from django.utils.translation import ugettext as _  # noqa
@@ -23,29 +23,13 @@ from horizon import exceptions
 from horizon import forms
 from horizon import messages
 
-from monitoring import api
 from monitoring.alarmdefs import constants
-
-
-def _get_metrics_call(request, offset=None):
-    return api.monitor.metrics_list(request, offset=offset)\
-        if offset else api.monitor.metrics_list(request)
+from monitoring import api
 
 
 def _get_metrics(request):
-    metrics_aggregation = _get_metrics_call(request)
-    if not metrics_aggregation:
-        return []
-    # offset defined as the id of last metric.
-    offset = metrics_aggregation[-1]['id']
-    while True:
-        metrics_batch = _get_metrics_call(request, offset)
-        if not metrics_batch:
-            break
-        metrics_aggregation += metrics_batch
-        offset = metrics_batch[-1]['id']
-
-    return json.dumps(metrics_aggregation)
+    metrics = api.monitor.metrics_list(request)
+    return json.dumps(metrics)
 
 
 def _get_notifications(request):
@@ -244,7 +228,8 @@ class EditAlarmForm(forms.SelfHandlingForm):
             notifications = []
             exceptions.handle(request,
                               _('Unable to retrieve notifications: %s') % e)
-        notification_choices = [(notification['id'], notification) for notification in notifications]
+        notification_choices = [
+            (notification['id'], notification) for notification in notifications]
 
         self.fields['notifications'].choices = notification_choices
 
