@@ -14,12 +14,12 @@
 # under the License.
 
 from django.core import urlresolvers
-from mock import patch, call  # noqa
+from mock import patch
 
-from monitoring.test import helpers
 from monitoring.alarmdefs import constants
 from monitoring.alarmdefs import views
 from monitoring.alarmdefs import workflows
+from monitoring.test import helpers
 
 
 INDEX_URL = urlresolvers.reverse(
@@ -33,7 +33,6 @@ EDIT_URL = urlresolvers.reverse(
 
 
 class AlarmDefinitionsTest(helpers.TestCase):
-
     def test_alarmdefs_get(self):
         with patch('monitoring.api.monitor', **{
             'spec_set': ['alarmdef_list'],
