@@ -15,10 +15,13 @@
 import logging
 
 from django.contrib import messages
-from django.core.paginator import Paginator, EmptyPage
-from django.core.urlresolvers import reverse_lazy, reverse  # noqa
+from django.core.paginator import EmptyPage
+from django.core.paginator import Paginator
+from django.core.urlresolvers import reverse
+from django.core.urlresolvers import reverse_lazy
 from django.utils.translation import ugettext as _  # noqa
-from django.views.generic import TemplateView  # noqa
+from django.views.generic import TemplateView
+import six
 
 from horizon import exceptions
 from horizon import forms
@@ -154,7 +157,7 @@ class AlarmDetailView(TemplateView):
                 except exc.HttpError:
                     msg = _("Notification %s has already been deleted.") % id
                     notifications.append({"id": id,
-                                          "name": unicode(msg),
+                                          "name": six.text_type(msg),
                                           "type": "",
                                           "address": ""})
 
