@@ -1,4 +1,5 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
+# Copyright 2017 FUJITSU LIMITED
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -16,16 +17,16 @@ import re
 
 from django import forms as django_forms
 from django.template.loader import get_template
-from django.template import Context
 from django.utils import html
 from django.utils.translation import ugettext_lazy as _  # noqa
+import six
 
 from horizon import exceptions
 from horizon import forms
 from horizon import messages
 
-from monitoring import api
 from monitoring.alarms import constants
+from monitoring import api
 
 
 class ExpressionWidget(forms.Widget):
@@ -34,7 +35,7 @@ class ExpressionWidget(forms.Widget):
         self.initial = initial
 
     def render(self, name, value, attrs):
-        final_attrs = self.build_attrs(attrs, name=name)
+        final_attrs = self.build_attrs(attrs, {'name': name})
         if value:
             dim = value
         else:
@@ -45,8 +46,8 @@ class ExpressionWidget(forms.Widget):
         t = get_template(constants.TEMPLATE_PREFIX + 'expression_field.html')
         local_attrs = {'service': dim}
         local_attrs.update(final_attrs)
-        context = Context(local_attrs)
-        return t.render(context)
+
+        return t.render(local_attrs)
 
 
 class SimpleExpressionWidget(django_forms.MultiWidget):
@@ -116,7 +117,7 @@ class NotificationCreateWidget(forms.Select):
         output = '<table id="notification_table" ' + \
             'class="table table-condensed">'
         output += '<thead><tr><th>%s</th></tr></thead>' % \
-            unicode(_("Name"))
+            six.text_type(_("Name"))
         if value:
             idx = 1
             for notification in value:
@@ -143,7 +144,7 @@ class NotificationCreateWidget(forms.Select):
             output += '<td><a href="" id="remove_notif_button">X</a></td>'
             output += '</td></tr>'
         output += '</table>'
-        label = unicode(_("+ Add more"))
+        label = six.text_type(_("+ Add more"))
         output += '<a href="" id="add_notification_button">%s</a>' % (label)
         return html.format_html(output)
 
@@ -221,10 +222,10 @@ class BaseAlarmForm(forms.SelfHandlingForm):
         if notification_choices:
             if len(notification_choices) > 1:
                 notification_choices.insert(
-                    0, ("", unicode(_("Select Notification"))))
+                    0, ("", six.text_type(_("Select Notification"))))
         else:
             notification_choices.insert(
-                0, ("", unicode(_("No notifications available."))))
+                0, ("", six.text_type(_("No notifications available."))))
 
         self.fields['notifications'].choices = notification_choices
 
