@@ -24,9 +24,9 @@ from django.utils.translation import ungettext_lazy
 from horizon import tables
 
 from monitoring.alarms import constants
+from monitoring import api
 from monitoring.config import local_settings
 from monitoring.overview import constants as ov_constants
-from monitoring import api
 
 
 STATUS = ["OK", "WARNING", "CRITICAL", "UNKNOWN"]
@@ -66,8 +66,9 @@ def show_alarm_id(data):
     return data['id']
 
 
-def show_metric_name(data):
-    return data['metrics'][0]['name']
+def show_metric_names(data):
+    names = set(metric['name'] for metric in data['metrics'])
+    return ', '.join(names)
 
 
 def show_def_name(data):
@@ -166,7 +167,7 @@ class GraphMetric(tables.LinkAction):
             metric = datum['metrics'][0]['name']
             dimensions = datum['metrics'][0].get('dimensions', {})
             query = "?metric=%s" % metric
-            for key, value in dimensions.iteritems():
+            for key, value in dimensions.items():
                 query += "&dim_%s=%s" % (key, value)
         except AttributeError:
             # Catches case where Grafana 2 is not enabled.
@@ -242,8 +243,8 @@ class AlarmsTable(tables.DataTable):
                           filters=[show_status, template.defaultfilters.safe])
     name = tables.Column(transform=show_def_name, verbose_name=_('Name'))
     alarmId = tables.Column(transform=show_alarm_id, verbose_name=_('Alarm Id'))
-    metrics = tables.Column(transform=show_metric_name,
-                            verbose_name=_('Metric Name'))
+    metrics = tables.Column(transform=show_metric_names,
+                            verbose_name=_('Metric Names'))
     dimensions = tables.Column(transform=show_metric_dimensions,
                                verbose_name=_('Metric Dimensions'))
 
@@ -253,7 +254,7 @@ class AlarmsTable(tables.DataTable):
     def get_object_display(self, obj):
         return obj['id']
 
-    class Meta:
+    class Meta(object):
         name = "alarms"
         verbose_name = _("Alarms")
         row_actions = (GraphMetric,
@@ -284,6 +285,6 @@ class AlarmHistoryTable(tables.DataTable):
     def get_object_id(self, obj):
         return obj['alarm_id'] + obj['timestamp']
 
-    class Meta:
+    class Meta(object):
         name = "history"
         verbose_name = _("Alarm History")
