@@ -11,10 +11,11 @@
 #  under the License.
 
 from django.core import urlresolvers
-from mock import patch, call  # noqa
+from mock import patch
 
-from monitoring.test import helpers
 from monitoring.alarms import constants
+from monitoring.alarms import tables
+from monitoring.test import helpers
 
 
 INDEX_URL = urlresolvers.reverse(
@@ -26,6 +27,7 @@ ALARMS_URL = urlresolvers.reverse(
 
 
 class AlarmsTest(helpers.TestCase):
+
     def test_alarms_get_by_dimension(self):
         with patch('monitoring.api.monitor', **{
             'spec_set': ['alarm_list_by_dimension'],
@@ -47,3 +49,20 @@ class AlarmsTest(helpers.TestCase):
 
         self.assertTemplateUsed(
             res, 'monitoring/alarms/alarm.html')
+
+    def test_metric_conversion_single(self):
+        res = tables.show_metric_names({"metrics": [{"name": "mem.used_bytes"}]})
+        self.assertEqual(res, "mem.used_bytes")
+
+    def test_metric_conversion_multiple(self):
+        res = tables.show_metric_names({"metrics": [{"name": "mem.used_bytes"},
+                                                    {"name": "mem.total_bytes"}]})
+        table_res = res.split(', ')
+        self.assertEqual(len(table_res), 2)
+        self.assertTrue("mem.used_bytes" in table_res)
+        self.assertTrue("mem.total_bytes" in table_res)
+
+    def test_metric_conversion_unique(self):
+        res = tables.show_metric_names({"metrics": [{"name": "mem.used_bytes"},
+                                                    {"name": "mem.used_bytes"}]})
+        self.assertEqual(res, "mem.used_bytes")
