@@ -16,24 +16,24 @@ import base64
 import copy
 import json
 import logging
-import urllib
-import urllib2
 
-from django import http
 from django.contrib import messages
 from django.core.urlresolvers import reverse_lazy
-from django.http import HttpResponse  # noqa
+from django import http
+from django.http import HttpResponse
 from django.utils.translation import ugettext_lazy as _  # noqa
-from django.views import generic
 from django.views.decorators.csrf import csrf_exempt
-from django.views.generic import TemplateView  # noqa
+from django.views import generic
+from django.views.generic import TemplateView
 from openstack_auth import utils as auth_utils
 from openstack_dashboard import policy
+import six
+from six.moves import urllib
 
 from horizon import exceptions
 
-from monitoring import api
 from monitoring.alarms import tables as alarm_tables
+from monitoring import api
 from monitoring.config import local_settings as settings
 from monitoring.overview import constants
 
@@ -79,8 +79,8 @@ def get_dashboard_links(request):
     non_project_keys = {'fileName', 'title'}
     try:
         for project_link in settings.DASHBOARDS:
-            key = project_link.keys()[0]
-            value = project_link.values()[0]
+            key = list(project_link)[0]
+            value = list(project_link.values())[0]
             if key in non_project_keys:
                 #
                 # we're not indexed by project, just return
@@ -129,8 +129,8 @@ def get_monitoring_services(request):
     non_project_keys = {'name', 'groupBy'}
     try:
         for group in settings.MONITORING_SERVICES:
-            key = group.keys()[0]
-            value = group.values()[0]
+            key = list(group.keys())[0]
+            value = list(group.values())[0]
             if key in non_project_keys:
                 #
                 # we're not indexed by project, just return
@@ -162,15 +162,11 @@ def get_monitoring_services(request):
 
 
 def show_by_dimension(data, dim_name):
-    if 'metrics' in data:
-        dimensions = []
-        for metric in data['metrics']:
-            if 'dimensions' in metric:
-                if dim_name in metric['dimensions']:
-                    dimensions.append(str(metric['dimensions'][dim_name].encode('utf-8')))
-
-        return dimensions
-    return []
+    if 'dimensions' in data['metrics'][0]:
+        dimensions = data['metrics'][0]['dimensions']
+        if dim_name in dimensions:
+            return str(data['metrics'][0]['dimensions'][dim_name].encode('utf-8'))
+    return ""
 
 
 def get_status(alarms):
@@ -198,15 +194,14 @@ def generate_status(request):
         service_alarms.append(a)
     monitoring_services = copy.deepcopy(get_monitoring_services(request))
     for row in monitoring_services:
-        row['name'] = unicode(row['name'])
+        row['name'] = six.text_type(row['name'])
         if 'groupBy' in row:
             alarms_by_group = {}
             for a in alarms:
-                groups = show_by_dimension(a, row['groupBy'])
-                if groups:
-                    for group in groups:
-                        group_alarms = alarms_by_group.setdefault(group, [])
-                        group_alarms.append(a)
+                group = show_by_dimension(a, row['groupBy'])
+                if group:
+                    group_alarms = alarms_by_group.setdefault(group, [])
+                    group_alarms.append(a)
             services = []
             for group, group_alarms in alarms_by_group.items():
                 name = '%s=%s' % (row['groupBy'], group)
@@ -225,7 +220,7 @@ def generate_status(request):
                 service_alarms = alarms_by_service.get(service['name'], [])
                 service['class'] = get_status(service_alarms)
                 service['icon'] = get_icon(service['class'])
-                service['display'] = unicode(service['display'])
+                service['display'] = six.text_type(service['display'])
     return monitoring_services
 
 
@@ -249,7 +244,8 @@ class IndexView(TemplateView):
         for link in context["dashboards"]:
             link['raw'] = link.get('raw', False)
         context['can_access_logs'] = policy.check(
-            ((getattr(settings, 'KIBANA_POLICY_SCOPE'), getattr(settings, 'KIBANA_POLICY_RULE')), ), self.request
+            ((getattr(settings, 'KIBANA_POLICY_SCOPE'), getattr(settings, 'KIBANA_POLICY_RULE')), ),
+            self.request
         )
         context['enable_kibana_button'] = settings.ENABLE_KIBANA_BUTTON
         context['show_grafana_home'] = settings.SHOW_GRAFANA_HOME
@@ -260,7 +256,9 @@ class MonascaProxyView(TemplateView):
     template_name = ""
 
     def _convert_dimensions(self, req_kwargs):
-        """this method converts the dimension string
+        """Converts the dimension string service:monitoring into a dict
+
+        This method converts the dimension string
         service:monitoring  (requested by a query string arg)
         into a python dict that looks like
         {"service": "monitoring"} (used by monasca api calls)
@@ -276,7 +274,7 @@ class MonascaProxyView(TemplateView):
                 if len(dimension_name_value) == 2:
                     name = dimension_name_value[0].encode('utf8')
                     value = dimension_name_value[1].encode('utf8')
-                    dim_dict[name] = urllib.unquote(value)
+                    dim_dict[name] = urllib.parse.unquote(value)
                 else:
                     raise Exception('Dimensions are malformed')
 
@@ -315,7 +313,7 @@ class MonascaProxyView(TemplateView):
                                                     **req_kwargs)}
         if not results:
             LOG.warning("There was a request made for the path %s that"
-                     " is not supported." % restpath)
+                        " is not supported." % restpath)
             results = {}
         return HttpResponse(json.dumps(results),
                             content_type='application/json')
@@ -334,10 +332,10 @@ class StatusView(TemplateView):
                             content_type='application/json')
 
 
-class _HttpMethodRequest(urllib2.Request):
+class _HttpMethodRequest(urllib.request.Request):
 
     def __init__(self, method, url, **kwargs):
-        urllib2.Request.__init__(self, url, **kwargs)
+        urllib.request.Request.__init__(self, url, **kwargs)
         self.method = method
 
     def get_method(self):
@@ -364,15 +362,15 @@ class KibanaProxyView(generic.View):
             method, proxy_request_url, data=data, headers=headers
         )
         try:
-            response = urllib2.urlopen(proxy_request)
+            response = urllib.request.urlopen(proxy_request)
 
-        except urllib2.HTTPError as e:
+        except urllib.error.HTTPError as e:
             return http.HttpResponse(
                 e.read(),
                 status=e.code,
                 content_type=e.hdrs['content-type']
             )
-        except urllib2.URLError as e:
+        except urllib.error.URLError as e:
             return http.HttpResponse(e.reason, 404)
 
         else:
@@ -411,7 +409,7 @@ class KibanaProxyView(generic.View):
         return self.read(request.method, url, request.body, headers)
 
     def get_relative_url(self, url):
-        url = urllib.quote(url.encode('utf-8'))
+        url = urllib.parse.quote(url.encode('utf-8'))
         params_str = self.request.GET.urlencode()
 
         if params_str:
@@ -423,5 +421,6 @@ class KibanaProxyView(generic.View):
 
     def _can_access_kibana(self):
         return policy.check(
-            ((getattr(settings, 'KIBANA_POLICY_SCOPE'), getattr(settings, 'KIBANA_POLICY_RULE')), ), self.request
+            ((getattr(settings, 'KIBANA_POLICY_SCOPE'), getattr(settings, 'KIBANA_POLICY_RULE')), ),
+            self.request
         )
